@@ -3,7 +3,7 @@
 State tracking functionality for django models
 """
 from django_fsm.db.fields.fsmfield import (  # NOQA
-    FSMField, FSMKeyField,
+    FSMField, FSMKeyField, FSMIntegerField,
     TransitionNotAllowed,
     transition,
     can_proceed)
